@@ -17,10 +17,17 @@ sub nested_names {
         while ( defined( $parent = $parent->parent ) ) {
 
             if ( $parent->can('is_field') && $parent->is_field ) {
+                # handling Field
                 push @names, $parent->name
                     if defined $parent->name;
             }
+            elsif ( $parent->can('is_repeatable') && $parent->is_repeatable ) {
+                # handling Repeatable
+                # ignore Repeatables nested_name attribute as it is provided
+                # by the childrens Block elements
+            }
             else {
+                # handling 'not Field' and 'not Repeatable'
                 push @names, $parent->nested_name
                     if defined $parent->nested_name;
             }
